using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Runtime.InteropServices;

namespace csWallChange
{
    public partial class Form1 : Form
    {

        //public MySettings settings = new MySettings("settings.xml");
        private string startuppath;
        private SettingsDialog settingsdialog = null;
        private MyAboutBox abtBox;


        //DllImport to change wallpaper...
        [DllImport("User32.dll")]
        public static extern bool SystemParametersInfo(int uiAction, int uiParam, int[] pvParam, int fWinIni);
        [DllImport("User32.dll")]
        public static extern bool SystemParametersInfo(int uiAction, int uiParam, string pvParam, int fWinIni);
        const int SPI_SET_WALLPAPER = 0x14;



        public Form1() {
            startuppath = Application.StartupPath;
            InitializeComponent();
        }

        public Form1(bool ignored) {
            startuppath = Application.StartupPath;
            txtFilename = new TextBox();
        }

        private void panel1_Paint(object sender, PaintEventArgs e) {
            System.Drawing.Drawing2D.LinearGradientBrush lb =
                new System.Drawing.Drawing2D.LinearGradientBrush(
                    new Point(),
                    new Point(0, panel1.Height - 1),
                    Color.FromArgb(192, 192, 192),
                    Color.FromArgb(215, 215, 215));
            e.Graphics.FillRectangle(lb, 0, 0, panel1.Width, panel1.Height);
            e.Graphics.DrawLine(Pens.White, 0, 1, panel1.Width, 1);
        }

        private void button1_Click(object sender, EventArgs e) {
            Application.Exit();
        }

        private void btnBrowse_Click(object sender, EventArgs e) {
            if (openFileDialog1.ShowDialog(this) == DialogResult.OK) {
                txtFilename.Text = openFileDialog1.FileName;
                showMetaData(txtFilename.Text);
            }
            
        }

        private void showMetaData(string p) {
            Bitmap bmp = (Bitmap)Bitmap.FromFile(p);
            int height = bmp.Height;
            int width = bmp.Width;
            double factor = pictureBox1.Width / (double)width;
            if (pictureBox1.Height / (double)height < factor)
                factor = pictureBox1.Height / (double)height;

            pictureBox1.Image = bmp.GetThumbnailImage((int)(factor * width), (int)(factor * height), null, IntPtr.Zero);
            pictureBox1.Refresh();

            lblName.Text = System.IO.Path.GetFileNameWithoutExtension(p);
            string ext = System.IO.Path.GetExtension(p);
            lblType.Text = ext.Substring(1);

            lblSize.Text = width + "  " + height;


        }

        private void btnChangeWall_Click(object sender, EventArgs e) {

            ChangeWallSilent(txtFilename.Text);
            
        }

        public  void ChangeWallSilent(string filename) {
            //Find out the screen resolution
            Rectangle r = Screen.GetBounds(this);
            int width = r.Width;
            int height = r.Height;

            //Load the image
            Bitmap org = null;
            try {
                org = (Bitmap)Bitmap.FromFile(filename);
            }
            catch (OutOfMemoryException) {
                MessageBox.Show(this, "Unrecognized File Format", "Error reading file",
                    MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            catch {
                MessageBox.Show(this, "Unknown Error", "Error reading file",
                    MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            //Make the new image to match screen resolution
            Bitmap bmp = new Bitmap(width, height);

            //Place the Image on the wallpaper (intelligently, if possible)
            WallpaperHelper.placeWallpaper(org, bmp);

            if (csWallChange.Properties.Settings.Default.DrawWallpaper) {
                Point p = WallpaperHelper.findCalendarLocation(bmp);
                WallpaperHelper.drawCalendar(bmp, p);
            }

            //Save it as a BMP format file
            string tempwp = System.IO.Path.Combine(startuppath, "wallpaper.bmp");
            bmp.Save(tempwp, System.Drawing.Imaging.ImageFormat.Bmp);

            //And change the wallpaper.
            SystemParametersInfo(SPI_SET_WALLPAPER, 0, tempwp, 0);
        }

        private void button4_Click(object sender, EventArgs e) {
            if (settingsdialog == null) {
                settingsdialog = new SettingsDialog();
            }
            DialogResult dr = settingsdialog.ShowDialog(this);
            if (dr == DialogResult.OK) {
                ckhCalendar.Checked = csWallChange.Properties.Settings.Default.DrawWallpaper;
            }
        }

        private void btnRandom_Click(object sender, EventArgs e) {
            string s = WallpaperHelper.getRandomWallpaper();
            if (s == null) {
                MessageBox.Show(this, "No Recognized Files in Search Path", "Error searching files",
                    MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            txtFilename.Text = s;
            showMetaData(s);
        }

        private void ckhCalendar_CheckedChanged(object sender, EventArgs e) {
            csWallChange.Properties.Settings.Default.DrawWallpaper = ckhCalendar.Checked;
            csWallChange.Properties.Settings.Default.Save();
        }

        private void button2_Click(object sender, EventArgs e) {
            if (abtBox == null) {
                abtBox = new MyAboutBox();
            }
            abtBox.ShowDialog(this);
        }




    }
}