using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace csWallChange
{
    public partial class SettingsDialog : Form
    {
        public SettingsDialog() {
            InitializeComponent();
            PopulateComponentChoices();
            //InsertValues();
        }


        public string[] highlightmethods =
            new string[] { "Underline", "Bold", "Italics", "Box", "Circle", "None" };
        csWallChange.Properties.Settings settings = csWallChange.Properties.Settings.Default;

        /// <summary>
        /// Fills up the different choices that are available to the user.
        /// </summary>
        private void PopulateComponentChoices() {

            //2-2. How to highlight today's date
            comboDateHighlight.Items.AddRange(highlightmethods);
        }


        /// <summary>
        /// This method checks whether the setting exists, and if not, inserts the default value there.
        /// </summary>
        private void InsertValues() {
            //1-1. Folder search path
            string s = settings.SearchFolder;
            if (string.IsNullOrEmpty(s)) {
                s = Environment.GetFolderPath(Environment.SpecialFolder.MyPictures);
            }
            txtSearchFolder.Text = s;

            //1-2. Search sub-folders
            bool b = settings.SearchSubFolders;
            if (b) chkSubFolders.CheckState = CheckState.Checked;
            else chkSubFolders.CheckState = CheckState.Unchecked;


            //2-1. Draw Wallpaper
            b = settings.DrawWallpaper;
            if (b) chkDrawWallpaper.CheckState = CheckState.Checked;
            else chkDrawWallpaper.CheckState = CheckState.Unchecked;


            //2-2. How to highlight today's date
            s = settings.TodayHighlightMethod;
            //Get the index
            int i = Array.IndexOf<string>(highlightmethods, s);
            if (i == -1) {
                //write the correct value to both settings and the drop-down
                settings.TodayHighlightMethod = highlightmethods[0];
                comboDateHighlight.SelectedIndex = 0;
            }
            else {
                comboDateHighlight.SelectedIndex = i;
            }
            
        }

        private void panel1_Paint(object sender, PaintEventArgs e) {
            System.Drawing.Drawing2D.LinearGradientBrush lb =
                new System.Drawing.Drawing2D.LinearGradientBrush(
                    new Point(),
                    new Point(0, panel1.Height - 1),
                    Color.FromArgb(192, 192, 192),
                    Color.FromArgb(215, 215, 215));
            //SolidBrush sb = new SolidBrush(Color.FromArgb(192, 192, 192));
            e.Graphics.FillRectangle(lb, 0, 0, panel1.Width, panel1.Height);
            e.Graphics.DrawLine(Pens.White, 0, 1, panel1.Width, 1);
        }

        private void btnApply_Click(object sender, EventArgs e) {
            settings.Save();
        }

        private void btnOK_Click(object sender, EventArgs e) {
            SyncAllSettings();
            settings.Save();
        }

        private void SyncAllSettings() {
            //1-1. Folder search path
            settings.SearchFolder = txtSearchFolder.Text;
            //1-2. Search Sub-Folders
            settings.SearchSubFolders = (chkSubFolders.CheckState == CheckState.Checked);

            //2-1. Draw Wallpaper?
            settings.DrawWallpaper = (chkDrawWallpaper.CheckState == CheckState.Checked);
            //2-2. TodayHighlightMethod
            settings.TodayHighlightMethod = highlightmethods[comboDateHighlight.SelectedIndex];
        }

        private void SettingsDialog_Load(object sender, EventArgs e) {
            if (string.IsNullOrEmpty(txtSearchFolder.Text)) {
                txtSearchFolder.Text = Environment.GetFolderPath(Environment.SpecialFolder.MyPictures);
            }
            InsertValues();
        }

        private void button1_Click(object sender, EventArgs e) {
            if (!string.IsNullOrEmpty(settings.SearchFolder)) {
                folderBrowserDialog1.SelectedPath = settings.SearchFolder;
            }
            else {
                folderBrowserDialog1.SelectedPath = Environment.GetFolderPath(Environment.SpecialFolder.MyPictures);
            }
            if (folderBrowserDialog1.ShowDialog(this) == DialogResult.OK) {
                txtSearchFolder.Text = folderBrowserDialog1.SelectedPath;
            }
        }


    }
}